.. _components:

Components
==========
This section lists detailed information about the
different modules of proFit.

.. toctree::
    :maxdepth: 2

    variables
    run_system
    surrogates
    active_learning
    mcmc
    ui
    extensions
